use-oci-platform
use-oci-platform provides OCI platform primitives for operating systems, architectures, variants, and platform rendering.
It is part of the use-oci RustUse workspace for small, focused OCI primitive crates. It does not perform network calls, shell out to runtimes, implement a registry client, or build container images.
License
Licensed under either of the following, at your option:
- Apache License, Version 2.0
- MIT license
Structs
- OciPlatform
- OCI platform metadata.
- OsFeature
- OsVersion
- Platform
Variant
Enums
- OciArchitecture
- OCI architecture labels.
- OciOs
- OCI operating system labels.
- Platform
Error - Errors returned while parsing OCI platform values.